@@ -6,7 +6,7 @@
 use v5.26;
 use Object::Pad 0.70;
 
-package Text::Treesitter::Node 0.06;
+package Text::Treesitter::Node 0.07;
 class Text::Treesitter::Node
    :strict(params);
 
@@ -183,6 +183,30 @@ used instead:
       ...
    }
 
+=head2 child_by_field_name
+
+   $child = $node->child_by_field_name( $field_name );
+
+I<Since version 0.07.>
+
+Returns the child node associated with the given field name. This would be the
+same as the value found by
+
+   my %children = $node->field_names_with_child_nodes;
+   $child = $children{ $field_name };
+
+If the node does not have a child with the given field name, an exception is
+thrown.
+
+=head2 try_child_by_field_name
+
+   $child = $node->try_child_by_field_name( $field_name );
+
+I<Since version 0.07.>
+
+Similar to L</child_by_field_name> but returns undef if there is no such child
+rather than throwing an exception.
+
 =cut
 
 method _node () { $node }
@@ -220,11 +244,22 @@ method field_names_with_child_nodes ()
    return pairmap { $a => Text::Treesitter::Node->new( node => $b, tree => $tree ) } $node->field_names_with_child_nodes;
 }
 
+method child_by_field_name ( $field_name )
+{
+   my $child = $node->child_by_field_name( $field_name );
+   return Text::Treesitter::Node->new( node => $child, tree => $tree )
+}
+
+method try_child_by_field_name ( $field_name )
+{
+   my $child = $node->try_child_by_field_name( $field_name ) or return;
+   return Text::Treesitter::Node->new( node => $child, tree => $tree )
+}
+
 =head1 TODO
 
 The following C library functions are currently unhandled:
 
-   ts_node_child_by_field_name
    ts_node_child_by_field_id
    ts_node_next_sibling
    ts_node_prev_sibling
